@@ -1,10 +1,13 @@
-using System.IO;
+using Gtk;
 using System;
+using System.IO;
+using System.Collections.Generic;
 using Mono.Unix;
 using NDesk.DBus;
 using org.freedesktop.DBus;
 
 using FSpot.UI.Dialog;
+using FSpot.Utils;
 
 namespace FSpot {
 	[Interface ("org.gnome.FSpot.Core")]
@@ -24,18 +27,13 @@ namespace FSpot {
 	{
 		MainWindow organizer;
 		private static Db db;
-		System.Collections.ArrayList toplevels;
+		List<Window> toplevels;
 		const string ServicePath = "org.gnome.FSpot";
 		static ObjectPath CorePath = new ObjectPath ("/org/gnome/FSpot/Core");
 
-		public Core () : this (false)
+		public Core ()
 		{
-		}
-
-		public Core (bool nodb)
-		{
-			toplevels = new System.Collections.ArrayList ();
-			
+			toplevels = new List<Window> ();
 		}
 
 		public static Db Database {
@@ -98,7 +96,10 @@ namespace FSpot {
 			{
 				if (path != null && path.StartsWith ("gphoto2:"))
 					main.ImportCamera (path);
-				else
+				else if (path != null && path.StartsWith ("file:")) {
+					Uri uri = new Uri (path);
+					main.ImportFile (Uri.UnescapeDataString (uri.AbsolutePath));
+				} else
 					main.ImportFile (path);
 				
 				return false;
@@ -158,18 +159,21 @@ namespace FSpot {
 				if (name != null)
 					tag = Database.Tags.GetTagByName (name);
 				else {
-					int id = (int) Preferences.Get (Preferences.SCREENSAVER_TAG);
+					int id = Preferences.Get<int> (Preferences.SCREENSAVER_TAG);
 					tag = Database.Tags.GetTagById (id);
 				}
 				
 				Photo [] photos;
 				if (tag != null)
 					photos = Database.Photos.Query (new Tag [] { tag } );
- 				else if ((int) Preferences.Get (Preferences.SCREENSAVER_TAG) == 0)
+ 				else if (Preferences.Get<int> (Preferences.SCREENSAVER_TAG) == 0)
  					photos = db.Photos.Query (new Tag [] {});
 				else
 					photos = new Photo [0];
 
+				double delay = Preferences.Get<double> (Preferences.APP_FSPOT + "screensaver/delay");
+				delay = Math.Max (1.0, delay);
+
 				window = new XScreenSaverSlide ();
 				SetStyle (window);
 				if (photos.Length > 0) {
@@ -177,7 +181,7 @@ namespace FSpot {
 					
 					Gdk.Pixbuf black = new Gdk.Pixbuf (Gdk.Colorspace.Rgb, false, 8, 1, 1);
 					black.Fill (0x00000000);
-					slideview = new SlideView (black, photos);
+					slideview = new SlideView (black, photos, delay);
 					window.Add (slideview);
 				} else {
 					Gtk.HBox outer = new Gtk.HBox ();
@@ -255,7 +259,7 @@ namespace FSpot {
 			}
 		}
 
-		public void Register (Gtk.Window window)
+		public void Register (Window window)
 		{
 			toplevels.Add (window);
 			window.Destroyed += HandleDestroyed;
@@ -267,13 +271,13 @@ namespace FSpot {
 
 		public void HandleDestroyed (object sender, System.EventArgs args)
 		{
-			toplevels.Remove (sender);
+			Log.Information ("Exiting");
+			toplevels.Remove (sender as Window);
 			if (toplevels.Count == 0) {
-				if (db != null)
-					db.EmitDown ();
-				// FIXME
-				// Should use Application.Quit(), but for that to work we need to terminate the threads
-				// first too.
+				Banshee.Kernel.Scheduler.Dispose ();
+				Core.Database.Dispose ();
+				ImageLoaderThread.Cleanup ();
+				Gtk.Application.Quit ();
 				System.Environment.Exit (0);
 			}
 			if (organizer != null && organizer.Window == sender)
