@@ -3,6 +3,8 @@ using System.IO;
 using System.Collections;
 using LibGPhoto2;
 using Gdk;
+using FSpot.Utils;
+using FSpot;
 
 public class GPhotoCamera
 {
@@ -69,11 +71,11 @@ public class GPhotoCamera
 
 		
 		string path  = camera_list.GetValue (selected_camera__camera_list_index);
-		System.Console.WriteLine ("Testing gphoto path = {0}", path);
+		Log.Debug ("Testing gphoto path = {0}", path);
 		selected_camera__port_info_list_index = port_info_list.LookupPath (path);
 
 		port_info = port_info_list.GetInfo (selected_camera__port_info_list_index);
-		System.Console.WriteLine ("PortInfo {0}, {1}", port_info.Name, port_info.Path);
+		Log.Debug ("PortInfo {0}, {1}", port_info.Name, port_info.Path);
 
 		camera.SetPortInfo (port_info);
 	}
@@ -167,7 +169,7 @@ public class GPhotoCamera
 									       CameraFileType.Preview,
 									       context);
 			} catch (System.Exception e) {
-				System.Console.WriteLine (e.ToString ());
+				Log.Exception (e);
 				selected_file.PreviewFile = null;
 			}
 		}
@@ -184,13 +186,15 @@ public class GPhotoCamera
 				MemoryStream dataStream = new MemoryStream (bytedata);
 				try {
 					Gdk.Pixbuf temp = new Pixbuf (dataStream);
-					FSpot.ColorManagement.ApplyScreenProfile (temp);
+					Cms.Profile screen_profile;
+					if (FSpot.ColorManagement.Profiles.TryGetValue (Preferences.Get<string> (Preferences.COLOR_MANAGEMENT_DISPLAY_PROFILE), out screen_profile)) 
+						FSpot.ColorManagement.ApplyProfile (temp, screen_profile);
 					return temp;
 				} catch (Exception e) {
 					// Actual errors with the data libgphoto gives us have been
 					// observed here see b.g.o #357569. 
-					Console.WriteLine ("Error retrieving preview image");
-					Console.WriteLine (e);
+					Log.Information ("Error retrieving preview image");
+					Log.DebugException (e);
 				}
 					
 			}
